@@ -185,7 +185,8 @@ comploglik_biv2 <- function(param,colidx,rowidx, corrmodel, coords,data1,data2,f
     if(all(model==45,likelihood==1,type==2)) fname <- 'Comp_Cond_BinomnegGaussZINB'  
     if(all(model==56,likelihood==1,type==2)) fname <- 'Comp_Cond_BinomnegGaussZINB1'                                       
     if(all(model==24,likelihood==1,type==2)) fname <- 'Comp_Cond_LogLogistic'                                        
-    if(all(model==25,likelihood==1,type==2)) fname <- 'Comp_Cond_Logistic'                                       
+    if(all(model==25,likelihood==1,type==2)) fname <- 'Comp_Cond_Logistic'
+    if(all(model==59,likelihood==1,type==2)) fname <- 'Comp_Cond_SkewLaplace'                                       
     if(all(model==41,likelihood==1,type==2)) fname <- 'Comp_Cond_Gauss_misp_Tukeygh'                                         
     if(all(model==37,likelihood==1,type==2)) fname <- 'Comp_Cond_Gauss_misp_SkewT'                                        
     if(all(model==47,likelihood==1,type==2)) fname <- 'Comp_Cond_Gauss_misp_PoisGamma'                          
@@ -214,7 +215,8 @@ comploglik_biv2 <- function(param,colidx,rowidx, corrmodel, coords,data1,data2,f
     if(all(model==50,likelihood==3,type==2)) fname <- 'Comp_Pair_Beta2'                                        
     if(all(model==26,likelihood==3,type==2)) fname <- 'Comp_Pair_Weibull'                                                                             
     if(all(model==24,likelihood==3,type==2)) fname <- 'Comp_Pair_LogLogistic'                                            
-    if(all(model==25,likelihood==3,type==2)) fname <- 'Comp_Pair_Logistic'                                                                                                                      
+    if(all(model==25,likelihood==3,type==2)) fname <- 'Comp_Pair_Logistic' 
+    if(all(model==59,likelihood==3,type==2)) fname <- 'Comp_Pair_SkewLaplace'                                                                                                                      
     if(all(model==23,likelihood==3,type==2)) fname <- 'Comp_Pair_2Gamma'                                                                               
     if(all(model==22,likelihood==3,type==2)) fname <- 'Comp_Pair_LogGauss';                                       
     if(all(model==18,likelihood==3,type==2)) fname <- 'Comp_Pair_SkewTGauss'                                         
