@@ -371,7 +371,11 @@ if (model %in% c("Weibull", "Poisson", "Binomial", "Gamma",
 conf.int=NULL
 pvalues=NULL
 
- initparam$coordz=coordz
+ #initparam$coordz=coordz
+
+if(all(initparam$coordz==0)) initparam$coordz=NULL
+
+
 if(likelihood=="Full"&&type=="Standard") 
 {
 
@@ -487,6 +491,7 @@ print.GeoFit <- function(x, digits = max(3, getOption("digits") - 3), ...)
   if(x$model=='Gamma2'){ process <- 'Gamma2'; model <- 'Gamma2'}
   if(x$model=='LogGauss'||x$model=='LogGaussian'){ process <- 'Log Gaussian'; model <- 'LogGaussian'}
   if(x$model=='SkewGauss'||x$model=='SkewGaussian'){ process <- 'Skew Gaussian';model <- 'SkewGaussian'}
+  if(x$model=='SkewLaplace'){ process <- 'Skew Laplace';model <- 'SkewLaplace'}
   if(x$model=='TwoPieceStudentT'){ process <- 'TwoPiece StudentT';model <- 'TwoPieceStudentT'}
   if(x$model=='TwoPieceTukeyh'){ process <- 'TwoPiece Tukeyh';model <- 'TwoPieceTukeyh'}
   if(x$model=='TwoPieceGaussian'||x$model=='TwoPieceGauss'){ process <- 'TwoPiece Gaussian';model <- 'TwoPieceGaussian'}
