@@ -219,7 +219,7 @@ else   { if(is.null(param$sill_1)) param$sill_1=1
     if(model %in% c("SkewGaussian","SkewGauss","Beta",'Kumaraswamy','Kumaraswamy2','LogGaussian',#"Binomial","BinomialNeg","BinomialNegZINB",
                     "StudentT","SkewStudentT","Poisson","TwoPieceTukeyh","PoissonZIP","PoissonGamma","PoissonGammaZIP","PoissonWeibull",
                      "TwoPieceBimodal", "TwoPieceStudentT","TwoPieceGaussian","TwoPieceGauss","Tukeyh","Tukeyh2","Tukeygh","SinhAsinh",
-                    "Gamma","Weibull","LogLogistic","Logistic","BinomialLogistic"))
+                    "Gamma","Weibull","LogLogistic","Logistic","SkewLaplace","BinomialLogistic"))
        {
         if(spacetime_dyn){env <- new.env();if(is.list(X))  X=do.call(rbind,args=c(X),envir = env)}
 
@@ -231,7 +231,7 @@ else   { if(is.null(param$sill_1)) param$sill_1=1
            param$mean=0;if(num_betas>1) {for(i in 1:(num_betas-1)) param[[paste("mean",i,sep="")]]=0}
         
 
-        if((model %in% c("SkewGaussian","SkewGauss","TwoPieceGaussian","Logistic",
+        if((model %in% c("SkewGaussian","SkewGauss","TwoPieceGaussian","Logistic","SkewLaplace",
           "TwoPieceGauss","Gamma","Weibull","LogLogistic","Poisson","PoissonZIP","Tukeyh","Tukeyh2","PoissonGamma",
           "PoissonGammaZIP","PoissonWeibull",
           'LogGaussian',"TwoPieceTukeyh","TwoPieceBimodal", "Tukeygh","SinhAsinh",
@@ -310,7 +310,7 @@ do_one_sim <- function(LL, pb = NULL) {
 ################################# how many random fields ################
     if(model %in% c("SkewGaussian","LogGaussian","TwoPieceGaussian","TwoPieceTukeyh")) k=1
     if(model %in% c("Weibull","Wrapped")) k=2
-    if(model %in% c("LogLogistic","Logistic")) k=4
+    if(model %in% c("LogLogistic","Logistic","SkewLaplace")) k=4
     if(model %in% c("Binomial"))   k=max(round(n))
     if(model %in% c("BinomialLogistic"))   k=2*max(round(n))
     if(model %in% c("Geometric","BinomialNeg","BinomialNegZINB")){ k=99999;
@@ -387,7 +387,7 @@ if(model %in% c("Binomial", "BinomialNeg","BinomialNegZINB")) {
 ####################################
 if(model %in% c("Weibull","SkewGaussian","SkewGauss","Binomial","BinomialLogistic","Poisson","PoissonGamma","PoissonWeibull","PoissonZIP","PoissonGammaZIP","Beta","Kumaraswamy","Kumaraswamy2",
               "LogGaussian","TwoPieceTukeyh",
-                "Gamma","LogLogistic","Logistic","StudentT",
+                "Gamma","LogLogistic","Logistic","SkewLaplace","StudentT",
                 "SkewStudentT","TwoPieceStudentT","TwoPieceGaussian","TwoPieceGauss","TwoPieceBimodal")) {
        if(!bivariate) dd[,,i]=t(sim)
        if(bivariate)  dd[,,i]=t(sim)
@@ -579,7 +579,7 @@ if(model %in% c("TwoPieceStudentT"))   {
 #########################################################################################################
 #### simulation for continuos random field  (on the positive real line) based on indipendent copies  of GRF ######
 #########################################################################################################
-if(model %in% c("LogLogistic","Logistic"))   {
+if(model %in% c("LogLogistic","Logistic","SkewLaplace"))   {
       sim1=sim2=NULL
     for(i in 1:2)  sim1=cbind(sim1,dd[,,i]^2)
     for(i in 3:4)  sim2=cbind(sim2,dd[,,i]^2)
@@ -594,6 +594,10 @@ if(model %in% c("LogLogistic","Logistic"))   {
       #sim=mm+log(exp(sim2)-1)*(vv)^(0.5)
      }
 
+        if(model %in% c("SkewLaplace"))  
+     {
+        sim=mm+(sim1/param$skew-sim2/(1-param$skew))*(vv)^(0.5)
+     }
 
   if(!grid)  {
                 if(!spacetime&&!bivariate) sim <- c(sim)
