@@ -11,4 +11,11 @@
                                     " (built on ", pkg.info["Date"], ") is now loaded\n", sep = ""),
                               "--------------------------------------------------------------\n"))
 
+}
+
+.GeoModels_env <- new.env(parent = emptyenv())
+
+.onLoad <- function(libname, pkgname) {
+  .GeoModels_env$II_global_cache <- new.env(hash = TRUE)
+  .GeoModels_env$ak_cache <- list()
 }
\ No newline at end of file
